# corgy


* [corgy package](corgy.md)


    * [`Corgy`](corgy.md#corgy.Corgy)
        * [`Corgy.add_args_to_parser()`](corgy.md#corgy.Corgy.add_args_to_parser)
        * [`Corgy.attrs()`](corgy.md#corgy.Corgy.attrs)
        * [`Corgy.is_attr_set()`](corgy.md#corgy.Corgy.is_attr_set)
        * [`Corgy.as_dict()`](corgy.md#corgy.Corgy.as_dict)
        * [`Corgy.from_dict()`](corgy.md#corgy.Corgy.from_dict)
        * [`Corgy.load_dict()`](corgy.md#corgy.Corgy.load_dict)
        * [`Corgy.parse_from_cmdline()`](corgy.md#corgy.Corgy.parse_from_cmdline)
        * [`Corgy.parse_from_toml()`](corgy.md#corgy.Corgy.parse_from_toml)
        * [`Corgy.freeze()`](corgy.md#corgy.Corgy.freeze)


    * [`corgychecker()`](corgy.md#corgy.corgychecker)
    * [`corgyparser()`](corgy.md#corgy.corgyparser)
    * [`CorgyHelpFormatter`](corgy.md#corgy.CorgyHelpFormatter)
        * [`CorgyHelpFormatter.using_colors`](corgy.md#corgy.CorgyHelpFormatter.using_colors)
        * [`CorgyHelpFormatter.ShortHelpAction`](corgy.md#corgy.CorgyHelpFormatter.ShortHelpAction)
            * [`CorgyHelpFormatter.ShortHelpAction.__call__()`](corgy.md#corgy.CorgyHelpFormatter.ShortHelpAction.__call__)


        * [`CorgyHelpFormatter.FullHelpAction`](corgy.md#corgy.CorgyHelpFormatter.FullHelpAction)
            * [`CorgyHelpFormatter.FullHelpAction.__call__()`](corgy.md#corgy.CorgyHelpFormatter.FullHelpAction.__call__)


        * [`CorgyHelpFormatter.add_short_full_helps()`](corgy.md#corgy.CorgyHelpFormatter.add_short_full_helps)


    * [Subpackages](corgy.md#subpackages)


        * [corgy.types package](corgy.types.md)


            * [`OutputTextFile`](corgy.types.md#corgy.types.OutputTextFile)
            * [`OutputBinFile`](corgy.types.md#corgy.types.OutputBinFile)
            * [`LazyOutputTextFile`](corgy.types.md#corgy.types.LazyOutputTextFile)
            * [`LazyOutputBinFile`](corgy.types.md#corgy.types.LazyOutputBinFile)
            * [`InputTextFile`](corgy.types.md#corgy.types.InputTextFile)
            * [`InputBinFile`](corgy.types.md#corgy.types.InputBinFile)
            * [`SubClass`](corgy.types.md#corgy.types.SubClass)
            * [`KeyValuePairs`](corgy.types.md#corgy.types.KeyValuePairs)
            * [`InitArgs`](corgy.types.md#corgy.types.InitArgs)
